@@ -32,7 +32,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "2.3.85", __name__[0:-6], "cdk-gitlab-runner@2.3.85.jsii.tgz"
+    "cdk-gitlab-runner",
+    "2.3.115",
+    __name__[0:-6],
+    "cdk-gitlab-runner@2.3.115.jsii.tgz",
 )
 
 __all__ = [
